@@ -1,4 +1,4 @@
-test_that("`palette_function()` works", {
+test_that('`palette_function()` works', {
   expect_true(is.function(palette_function(roygbiv)))
 
   expect_length(palette_function(roygbiv)(2), 2)
