@@ -1,5 +1,4 @@
-test_that("plotting works no vdiffr", {
-
+test_that('plotting works no vdiffr', {
   p <- plot(palette(roygbiv))
   expect_s3_class(p, 'gg')
   expect_length(p$data$col, 36) # length 7 -> 3x3 * 4 entries each
@@ -7,7 +6,7 @@ test_that("plotting works no vdiffr", {
   expect_null(plot_palette(named_pal, use_ggplot = FALSE))
 })
 
-test_that("plotting works with vdiffr", {
+test_that('plotting works with vdiffr', {
   skip_if_not_installed('vdiffr')
   vdiffr::expect_doppelganger(
     'plot-palette-ggplot',
@@ -19,5 +18,3 @@ test_that("plotting works with vdiffr", {
     plot_palette(named_pal, use_ggplot = FALSE)
   )
 })
-
-
